# idf-build-apps

## Contributing

### Type Annotation

For 2.7, 3.4-3.10 compatibility, we use type annotation in comments.

### IDF Compatibility

Need to support all the IDF versions under the maintenance period.
